@@ -36,14 +36,22 @@
 
 from __future__ import annotations
 
+import dataclasses
+import io
+import os
 import pathlib
-from dataclasses import asdict
-from typing import Literal, Optional, Union
+from typing import Literal
 
 import numpy as np
+from numpy.typing import ArrayLike, NDArray
 
 from phonopy import Phonopy
-from phonopy.exception import ForcesetsNotFoundError
+from phonopy.exception import (
+    ForcesetsNotFoundError,
+    PypolymlpDevelopmentError,
+    PypolymlpFileNotFoundError,
+    PypolymlpTrainingDatasetNotFoundError,
+)
 from phonopy.file_IO import (
     parse_BORN,
     parse_FORCE_CONSTANTS,
@@ -68,16 +76,16 @@ from phonopy.structure.dataset import forces_in_dataset
 
 
 def get_cell_settings(
-    supercell_matrix=None,
-    primitive_matrix=None,
-    unitcell=None,
-    supercell=None,
-    unitcell_filename=None,
-    supercell_filename=None,
-    calculator=None,
-    symprec=1e-5,
-    log_level=0,
-):
+    supercell_matrix: ArrayLike | None = None,
+    primitive_matrix: ArrayLike | str | None = None,
+    unitcell: PhonopyAtoms | None = None,
+    supercell: PhonopyAtoms | None = None,
+    unitcell_filename: str | os.PathLike | None = None,
+    supercell_filename: str | os.PathLike | None = None,
+    calculator: str | None = None,
+    symprec: float = 1e-5,
+    log_level: int = 0,
+) -> tuple[PhonopyAtoms, ArrayLike | None, str | NDArray | None]:
     """Return crystal structures."""
     optional_structure_info = None
     if primitive_matrix is None or (
@@ -125,13 +133,13 @@ def get_cell_settings(
 
 
 def get_nac_params(
-    primitive: Optional[Primitive] = None,
-    nac_params: Optional[dict] = None,
-    born_filename: Optional[str] = None,
+    primitive: Primitive | None = None,
+    nac_params: dict | None = None,
+    born_filename: str | os.PathLike | None = None,
     is_nac: bool = True,
-    nac_factor: Optional[float] = None,
+    nac_factor: float | None = None,
     log_level: int = 0,
-) -> dict:
+) -> dict | None:
     """Look for and return NAC parameters.
 
     Parameters
@@ -163,12 +171,20 @@ def get_nac_params(
 
     """
     if born_filename is not None:
+        if primitive is None:
+            raise ValueError(
+                "Primitive cell has to be specified when born_filename is given."
+            )
         _nac_params = parse_BORN(primitive, filename=born_filename)
         if log_level:
             print('NAC parameters were read from "%s".' % born_filename)
     elif nac_params is not None:  # nac_params input or phonopy_yaml.nac_params
         _nac_params = nac_params
     elif is_nac and pathlib.Path("BORN").exists():
+        if primitive is None:
+            raise ValueError(
+                "Primitive cell has to be specified when born_filename is given."
+            )
         _nac_params = parse_BORN(primitive, filename="BORN")
         if log_level:
             print('NAC params were read from "BORN".')
@@ -182,8 +198,10 @@ def get_nac_params(
 
 
 def read_force_constants_from_hdf5(
-    filename="force_constants.hdf5", p2s_map=None, calculator=None
-):
+    filename: str | os.PathLike = "force_constants.hdf5",
+    p2s_map: ArrayLike | None = None,
+    calculator: str | None = None,
+) -> NDArray:
     """Convert force constants physical unit.
 
     Each calculator interface has own default force constants physical unit.
@@ -207,27 +225,29 @@ def read_force_constants_from_hdf5(
 
 
 def select_and_load_dataset(
-    phonon: Phonopy,
-    dataset: Optional[dict],
-    phonopy_yaml_filename: Optional[str] = None,
-    force_sets_filename: Optional[str] = None,
+    nsatom: int,
+    dataset: dict | None = None,
+    phonopy_yaml_filename: str | os.PathLike | io.IOBase | None = None,
+    force_sets_filename: str | os.PathLike | None = None,
     log_level: int = 0,
-) -> Optional[dict]:
+) -> dict | None:
     """Set displacement-force dataset."""
-    natom = len(phonon.supercell)
     _dataset = None
     _force_sets_filename = None
     if forces_in_dataset(dataset):
         _dataset = dataset
-        _force_sets_filename = phonopy_yaml_filename
+        if isinstance(phonopy_yaml_filename, (str, os.PathLike)):
+            _force_sets_filename = phonopy_yaml_filename
     elif force_sets_filename is not None:
-        _dataset = parse_FORCE_SETS(natom=natom, filename=force_sets_filename)
+        _dataset = parse_FORCE_SETS(natom=nsatom, filename=force_sets_filename)
         _force_sets_filename = force_sets_filename
     elif pathlib.Path("FORCE_SETS").exists():
-        _dataset = parse_FORCE_SETS(natom=natom)
+        _dataset = parse_FORCE_SETS(natom=nsatom)
         _force_sets_filename = "FORCE_SETS"
     else:
         _dataset = dataset
+        if isinstance(phonopy_yaml_filename, (str, os.PathLike)):
+            _force_sets_filename = phonopy_yaml_filename
 
     if log_level:
         if forces_in_dataset(_dataset):
@@ -240,43 +260,33 @@ def select_and_load_dataset(
 
 def select_and_extract_force_constants(
     phonon: Phonopy,
-    phonopy_yaml_filename: Optional[str] = None,
-    fc: Optional[np.ndarray] = None,  # From phonopy_yaml
-    force_constants_filename: Optional[str] = None,
+    phonopy_yaml_filename: str | os.PathLike | None = None,
+    force_constants: NDArray | None = None,
+    force_constants_filename: str | os.PathLike | None = None,
     is_compact_fc: bool = True,
     log_level: int = 0,
-) -> Optional[np.ndarray]:
-    """Set force constants."""
+) -> NDArray | None:
+    """Extract force constants.
+
+    1. From fc (ndarray) in phonopy_yaml.
+    2. From FORCE_CONSTANTS file or force_constants.hdf5 file.
+
+    """
     _fc = None
     _force_constants_filename = None
-    if fc is not None:
-        _fc = fc
+    if force_constants is not None:  # 1
+        _fc = force_constants
         _force_constants_filename = phonopy_yaml_filename
-    elif force_constants_filename is not None:
-        _fc = _read_force_constants_file(
-            phonon,
-            force_constants_filename,
-            is_compact_fc=is_compact_fc,
-            log_level=log_level,
-        )
+    elif force_constants_filename is not None:  # 2
+        _fc = _read_force_constants_file(phonon, force_constants_filename)
         _force_constants_filename = force_constants_filename
     elif phonon.force_constants is None:
         # unless provided these from phonopy_yaml.
         if pathlib.Path("FORCE_CONSTANTS").exists():
-            _fc = _read_force_constants_file(
-                phonon,
-                "FORCE_CONSTANTS",
-                is_compact_fc=is_compact_fc,
-                log_level=log_level,
-            )
+            _fc = _read_force_constants_file(phonon, "FORCE_CONSTANTS")
             _force_constants_filename = "FORCE_CONSTANTS"
         elif pathlib.Path("force_constants.hdf5").exists():
-            _fc = _read_force_constants_file(
-                phonon,
-                "force_constants.hdf5",
-                is_compact_fc=is_compact_fc,
-                log_level=log_level,
-            )
+            _fc = _read_force_constants_file(phonon, "force_constants.hdf5")
             _force_constants_filename = "force_constants.hdf5"
 
     if _fc is not None:
@@ -290,33 +300,13 @@ def select_and_extract_force_constants(
     return _fc
 
 
-def prepare_pypolymlp_and_dataset(
-    phonon: Phonopy,
-    mlp_params: Optional[dict] = None,
-    displacement_distance: Optional[float] = None,
-    number_of_snapshots: Optional[Union[int, Literal["auto"]]] = None,
-    random_seed: Optional[int] = None,
-    prepare_dataset: bool = False,
-    log_level: int = 0,
-):
-    """Prepare pypolymlp and dataset."""
-    _run_pypolymlp(phonon, mlp_params, log_level=log_level)
-    if prepare_dataset:
-        _prepare_dataset_by_pypolymlp(
-            phonon,
-            displacement_distance=displacement_distance,
-            number_of_snapshots=number_of_snapshots,
-            random_seed=random_seed,
-            log_level=log_level,
-        )
-
-
 def produce_force_constants(
     phonon: Phonopy,
-    fc_calculator: Optional[str] = None,
-    fc_calculator_options: Optional[str] = None,
+    fc_calculator: Literal["traditional", "symfc", "alm"] | None = None,
+    fc_calculator_options: str | None = None,
     symmetrize_fc: bool = True,
     is_compact_fc: bool = True,
+    use_symfc_projector: bool = False,
     log_level: int = 0,
 ):
     """Produce force constants."""
@@ -327,12 +317,17 @@ def produce_force_constants(
             fc_calculator_options=fc_calculator_options,
         )
         if symmetrize_fc:
-            phonon.symmetrize_force_constants(show_drift=(log_level > 0))
-            if log_level:
-                print("Force constants were symmetrized.")
+            if fc_calculator is None:
+                phonon.symmetrize_force_constants(
+                    show_drift=True, use_symfc_projector=use_symfc_projector
+                )
+            elif fc_calculator == "traditional":
+                phonon.symmetrize_force_constants(
+                    show_drift=True, use_symfc_projector=False
+                )
     except ForcesetsNotFoundError:
         if log_level:
-            print("Displacement-force datast was not found. ")
+            print("Displacement-force dataset was not found. ")
 
 
 def check_nac_params(nac_params: dict, unitcell: PhonopyAtoms, pmat: np.ndarray):
@@ -343,66 +338,125 @@ def check_nac_params(nac_params: dict, unitcell: PhonopyAtoms, pmat: np.ndarray)
         raise ValueError(msg)
 
 
-def _run_pypolymlp(
+def develop_or_load_pypolymlp(
     phonon: Phonopy,
-    mlp_params: Union[str, dict, PypolymlpParams],
+    mlp_params: str | dict | PypolymlpParams | None = None,
+    mlp_filename: str | os.PathLike | None = None,
     log_level: int = 0,
 ):
     """Run pypolymlp to compute forces."""
     if log_level:
         print("-" * 29 + " pypolymlp start " + "-" * 30)
-        print("Pypolymlp is a generator of polynomial machine learning potentials.")
-        print("Please cite the paper: A. Seko, J. Appl. Phys. 133, 011101 (2023).")
-        print("Pypolymlp is developed at https://github.com/sekocha/pypolymlp.")
-        if mlp_params:
-            print("Parameters:")
-            for k, v in asdict(parse_mlp_params(mlp_params)).items():
-                if v is not None:
-                    print(f"  {k}: {v}")
+        _show_pypolymlp_header(mlp_params=mlp_params)
 
-    mlp_loaded = False
-    for mlp_filename in ["polymlp.yaml", "phonopy.pmlp"]:
-        _mlp_filename_list = list(pathlib.Path().glob(f"{mlp_filename}*"))
-        if _mlp_filename_list:
-            _mlp_filename = _mlp_filename_list[0]
-            if _mlp_filename.suffix not in [
-                ".yaml",
-                ".pmlp",
-                ".xz",
-                ".gz",
-                ".bz2",
-                "lzma",
-            ]:
-                continue
-            if log_level:
-                print(f'Load MLPs from "{_mlp_filename}".')
-            phonon.load_mlp(_mlp_filename)
-            mlp_loaded = True
-            if log_level and mlp_filename == "phonopy.pmlp":
-                print(f'Loading MLPs from "{_mlp_filename}" is obsolete.')
-            break
+    _load_pypolymlp(phonon, mlp_filename=mlp_filename, log_level=log_level)
 
-    mlp_filename = "polymlp.yaml"
-    if not mlp_loaded:
-        if forces_in_dataset(phonon.mlp_dataset):
-            if log_level:
-                print("Developing MLPs by pypolymlp...", flush=True)
-            phonon.develop_mlp(params=mlp_params)
-            phonon.save_mlp()
-            if log_level:
-                print(f'MLPs were written into "{mlp_filename}"', flush=True)
-        else:
-            raise RuntimeError(f'"{mlp_filename}" is not found.')
+    if phonon.mlp is None:
+        _develop_and_save_pypolymlp(
+            phonon,
+            mlp_params=mlp_params,
+            mlp_filename=mlp_filename,
+            log_level=log_level,
+        )
 
     if log_level:
         print("-" * 30 + " pypolymlp end " + "-" * 31, flush=True)
 
 
-def _prepare_dataset_by_pypolymlp(
+def _show_pypolymlp_header(mlp_params: str | dict | PypolymlpParams | None = None):
+    """Show pypolymlp header."""
+    import pypolymlp
+
+    print(f"Pypolymlp version {pypolymlp.__version__}")
+    print("Pypolymlp is a generator of polynomial machine learning potentials.")
+    print("Please cite the paper: A. Seko, J. Appl. Phys. 133, 011101 (2023).")
+    print("Pypolymlp is developed at https://github.com/sekocha/pypolymlp.")
+
+
+def _load_pypolymlp(
     phonon: Phonopy,
-    displacement_distance: Optional[float] = None,
-    number_of_snapshots: Optional[Union[int, Literal["auto"]]] = None,
-    random_seed: Optional[int] = None,
+    mlp_filename: str | os.PathLike | None = None,
+    log_level: int = 0,
+):
+    """Load MLPs from polymlp.yaml or phonopy.pmlp."""
+    _mlp_filename = None
+    if mlp_filename is None:
+        for default_mlp_filename in ["polymlp.yaml", "phonopy.pmlp", "phono3py.pmlp"]:
+            _mlp_filename_list = list(pathlib.Path().glob(f"{default_mlp_filename}*"))
+            if _mlp_filename_list:
+                _mlp_filename = _mlp_filename_list[0]
+                if _mlp_filename.suffix not in [
+                    ".yaml",
+                    ".pmlp",
+                    ".xz",
+                    ".gz",
+                    ".bz2",
+                    "lzma",
+                ]:
+                    continue
+                if log_level and "pmlp" in default_mlp_filename:
+                    print(f'Loading MLPs from "{_mlp_filename}" is obsolete.')
+                break
+    else:
+        _mlp_filename = mlp_filename
+
+    if _mlp_filename is None:
+        return None
+
+    if log_level:
+        print(f'Load MLPs from "{_mlp_filename}".')
+
+    if not pathlib.Path(_mlp_filename).exists():
+        raise PypolymlpFileNotFoundError(f'"{_mlp_filename}" is not found.')
+
+    phonon.load_mlp(_mlp_filename)
+
+
+def _develop_and_save_pypolymlp(
+    phonon: Phonopy,
+    mlp_params: str | dict | PypolymlpParams | None = None,
+    mlp_filename: str | os.PathLike | None = None,
+    log_level: int = 0,
+):
+    """Develop MLPs by pypolymlp and save them into polymlp.yaml."""
+    if forces_in_dataset(phonon.mlp_dataset):
+        if log_level:
+            if mlp_params is None:
+                pmlp_params = PypolymlpParams()
+            else:
+                pmlp_params = parse_mlp_params(mlp_params)
+            print("Parameters:")
+            for k, v in dataclasses.asdict(pmlp_params).items():
+                if v is not None:
+                    print(f"  {k}: {v}")
+            print("Developing MLPs by pypolymlp...", flush=True)
+
+        try:
+            phonon.develop_mlp(params=mlp_params)
+        except PypolymlpDevelopmentError as e:
+            if log_level:
+                print("-" * 30 + " pypolymlp end " + "-" * 31, flush=True)
+            raise PypolymlpDevelopmentError(str(e)) from e
+
+        if mlp_filename is None:
+            _mlp_filename = "polymlp.yaml"
+        else:
+            _mlp_filename = mlp_filename
+        phonon.save_mlp(filename=_mlp_filename)
+        if log_level:
+            print(f'MLPs were written into "{_mlp_filename}"', flush=True)
+    else:
+        raise PypolymlpTrainingDatasetNotFoundError(
+            "Pypolymlp training dataset is not found."
+        )
+
+
+def prepare_dataset_by_pypolymlp(
+    phonon: Phonopy,
+    displacement_distance: float | None = None,
+    number_of_snapshots: int | Literal["auto"] | None = None,
+    rd_number_estimation_factor: float | None = None,
+    random_seed: int | None = None,
     log_level: int = 0,
 ):
     """Generate displacements and evaluate forces by pypolymlp."""
@@ -430,7 +484,10 @@ def _prepare_dataset_by_pypolymlp(
         is_plusminus=True,
         number_of_snapshots=number_of_snapshots,
         random_seed=random_seed,
+        number_estimation_factor=rd_number_estimation_factor,
     )
+    assert phonon.supercells_with_displacements is not None
+
     if log_level and number_of_snapshots == "auto":
         print(
             "  Number of generated supercells with random displacements: "
@@ -443,15 +500,10 @@ def _prepare_dataset_by_pypolymlp(
             flush=True,
         )
 
-    if phonon.supercells_with_displacements is None:
-        raise RuntimeError("Displacements are not set. Run generate_displacements.")
-
     phonon.evaluate_mlp()
 
 
-def _read_force_constants_file(
-    phonon: Phonopy, force_constants_filename, is_compact_fc=True, log_level=0
-):
+def _read_force_constants_file(phonon: Phonopy, force_constants_filename) -> NDArray:
     dot_split = force_constants_filename.split(".")
     p2s_map = phonon.primitive.p2s_map
     if len(dot_split) > 1 and dot_split[-1] == "hdf5":
