@@ -135,8 +135,8 @@ class GruneisenMesh(GruneisenBase):
                 self._write_yaml(w, comment, is_binary=True)
 
     def _write_yaml(self, w, comment, is_binary=False):
-        natom = self._cell.get_number_of_atoms()
-        rec_lattice = np.linalg.inv(self._cell.get_cell())  # column vectors
+        natom = len(self._cell)
+        rec_lattice = np.linalg.inv(self._cell.cell)  # column vectors
         text = []
         text.append("mesh: [ %5d, %5d, %5d ]" % tuple(self._mesh))
         text.append("nqpoint: %d" % len(self._qpoints))
