@@ -34,6 +34,8 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import annotations
+
 import warnings
 from typing import TYPE_CHECKING
 
@@ -67,7 +69,7 @@ def get_commensurate_points(supercell_matrix):  # wrt primitive cell
     """
     smat = np.array(supercell_matrix, dtype=int)
     rec_primitive = PhonopyAtoms(
-        numbers=[1], scaled_positions=[[0, 0, 0]], cell=np.diag([1, 1, 1])
+        symbols=["H"], scaled_positions=[[0, 0, 0]], cell=np.diag([1, 1, 1])
     )
     rec_supercell = get_supercell(rec_primitive, smat.T)
     q_pos = rec_supercell.scaled_positions
@@ -100,7 +102,6 @@ def get_commensurate_points_in_integers(supercell_matrix):
     """
     smat = np.array(supercell_matrix, dtype=int)
     snf = SNF3x3(smat.T)
-    snf.run()
     D = snf.D.diagonal()
     b, c, a = np.meshgrid(range(D[1]), range(D[2]), range(D[0]))
     lattice_points = np.dot(
@@ -429,21 +430,19 @@ class DynmatToForceConstants:
             self._py_inverse_transformation()
 
         if self._fc.shape[0] == self._fc.shape[1]:
-            distribute_force_constants_by_translations(
-                self._fc, self._pcell, self._scell
-            )
+            distribute_force_constants_by_translations(self._fc, self._pcell)
 
     def _c_inverse_transformation(self):
         import phonopy._phonopy as phonoc
 
-        s2p = np.array(self._pcell.s2p_map, dtype="int_")
+        s2p = np.array(self._pcell.s2p_map, dtype="int64")
         p2p = self._pcell.p2p_map
-        s2pp = np.array([p2p[i] for i in s2p], dtype="int_")
+        s2pp = np.array([p2p[i] for i in s2p], dtype="int64")
 
         if self._fc.shape[0] == self._fc.shape[1]:
-            fc_index_map = np.array(self._pcell.p2s_map, dtype="int_")
+            fc_index_map = np.array(self._pcell.p2s_map, dtype="int64")
         else:
-            fc_index_map = np.arange(self._fc.shape[0], dtype="int_")
+            fc_index_map = np.arange(self._fc.shape[0], dtype="int64")
 
         phonoc.transform_dynmat_to_fc(
             self._fc,
