@@ -40,10 +40,11 @@ import dataclasses
 import io
 import os
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Optional, Union
+from typing import TYPE_CHECKING
 
 import numpy as np
 import yaml
+from numpy.typing import ArrayLike, NDArray
 
 from phonopy.structure.cells import Primitive, Supercell
 from phonopy.structure.symmetry import Symmetry
@@ -65,25 +66,25 @@ from phonopy.structure.dataset import forces_in_dataset
 class PhonopyYamlData:
     """PhonopyYaml data structure."""
 
-    configuration: Optional[dict] = None
-    calculator: Optional[str] = None
-    physical_units: Optional[dict] = None
-    unitcell: Optional[PhonopyAtoms] = None
-    primitive: Optional[Union[Primitive, PhonopyAtoms]] = None
-    supercell: Optional[Union[Supercell, PhonopyAtoms]] = None
-    dataset: Optional[dict] = None
-    supercell_matrix: Optional[np.ndarray] = None
-    primitive_matrix: Optional[np.ndarray] = None
-    nac_params: Optional[dict] = None
-    force_constants: Optional[np.ndarray] = None
-    symmetry: Optional[Symmetry] = None  # symmetry of supercell
-    frequency_unit_conversion_factor: Optional[float] = None
-    version: Optional[str] = None
+    configuration: dict | None = None
+    calculator: str | None = None
+    physical_units: dict | None = None
+    unitcell: PhonopyAtoms | None = None
+    primitive: Primitive | PhonopyAtoms | None = None
+    supercell: Supercell | PhonopyAtoms | None = None
+    dataset: dict | None = None
+    supercell_matrix: NDArray | None = None
+    primitive_matrix: NDArray | None = None
+    nac_params: dict | None = None
+    force_constants: NDArray | None = None
+    symmetry: Symmetry | None = None  # symmetry of supercell
+    frequency_unit_conversion_factor: float | None = None
+    version: str | None = None
     command_name: str = "phonopy"
 
 
-def phonopy_yaml_property_factory(name):
-    """Property factor for PhonopyYaml class."""
+def phonopy_yaml_property_factory(name) -> property:
+    """Property factory for PhonopyYaml class."""
 
     def getter(instance):
         return instance._data.__dict__[name]
@@ -194,8 +195,8 @@ class PhonopyYamlLoaderBase(ABC):
         pass
 
     def _get_dataset(
-        self, supercell: PhonopyAtoms, key_prefix: str = ""
-    ) -> Optional[dict]:
+        self, supercell: PhonopyAtoms | None, key_prefix: str = ""
+    ) -> dict | None:
         dataset = None
         if f"{key_prefix}displacements" in self._yaml:
             if supercell is not None:
@@ -216,8 +217,9 @@ class PhonopyYamlLoaderBase(ABC):
         return dataset
 
     def _parse_force_sets_type1(
-        self, natom: Optional[int] = None, key_prefix: str = ""
+        self, natom: int | None = None, key_prefix: str = ""
     ) -> dict:
+        dataset: dict
         key = f"{key_prefix}displacements"
         if "forces" in self._yaml[key][0]:
             dataset = {"natom": len(self._yaml[key][0]["forces"])}
@@ -291,6 +293,7 @@ class PhonopyYamlLoaderBase(ABC):
         ...
 
         """
+        dataset: dict
         key = f"{key_prefix}displacements"
         nsets = len(self._yaml[key])
         natom = len(self._yaml[key][0])
@@ -461,10 +464,10 @@ class PhonopyYamlDumperBase(ABC):
         dataset = self._data.symmetry.dataset
         if dataset is not None:
             try:
-                uni_number = dataset.uni_number
+                uni_number = dataset.uni_number  # type: ignore
                 lines.append("magnetic_space_group:")
                 lines.append(f"  uni_number: {uni_number}")
-                lines.append(f"  msg_type: {dataset.msg_type}")
+                lines.append(f"  msg_type: {dataset.msg_type}")  # type: ignore
                 lines.append("")
             except AttributeError:
                 lines.append("space_group:")
@@ -508,10 +511,10 @@ class PhonopyYamlDumperBase(ABC):
             lines.append("")
         return lines
 
-    def _primitive_yaml_lines(self, primitive: Primitive, name):
+    def _primitive_yaml_lines(self, primitive: PhonopyAtoms | None, name):
         lines = []
         if primitive is not None:
-            lines += self._cell_yaml_lines(self._data.primitive, name, None)
+            lines += self._cell_yaml_lines(primitive, name, None)
             lines.append("  reciprocal_lattice: # without 2pi")
             rec_lat = np.linalg.inv(primitive.cell)
             for v, a in zip(rec_lat.T, ("a*", "b*", "c*")):
@@ -547,7 +550,7 @@ class PhonopyYamlDumperBase(ABC):
         return lines
 
     def _cell_yaml_lines(
-        self, cell: PhonopyAtoms, name, map_to_primitive: Optional[list] = None
+        self, cell: PhonopyAtoms, name, map_to_primitive: list | None = None
     ):
         lines = []
         lines.append("%s:" % name)
@@ -560,10 +563,10 @@ class PhonopyYamlDumperBase(ABC):
         return lines
 
     @abstractmethod
-    def _nac_yaml_lines(self):
+    def _nac_yaml_lines(self) -> list:
         pass
 
-    def _nac_yaml_lines_given_symbols(self, symbols=None):
+    def _nac_yaml_lines_given_symbols(self, symbols=None) -> list:
         lines = []
         if self._data.nac_params is not None:
             if self._dumper_settings["born_effective_charge"]:
@@ -611,7 +614,7 @@ class PhonopyYamlDumperBase(ABC):
 
     def _displacements_yaml_lines_2types(
         self,
-        dataset: dict,
+        dataset: dict | None,
         with_forces: bool = False,
         key_prefix: str = "",
         v223_mode: bool = False,
@@ -661,6 +664,8 @@ class PhonopyYamlDumperBase(ABC):
         lines = [f"{key_prefix}dataset:"]
         if "random_seed" in dataset:
             lines.append("  random_seed: {:d}".format(dataset["random_seed"]))
+        if "cutoff_distance" in dataset:
+            lines.append("  cutoff_distance: {:5f}".format(dataset["cutoff_distance"]))
         for key in ("displacements", "forces"):
             if key not in dataset:
                 continue
@@ -740,7 +745,7 @@ class PhonopyYamlDumperBase(ABC):
                     lines.append("    - [ %21.15f, %21.15f, %21.15f ]" % tuple(v))
         return lines
 
-    def _init_dumper_settings(self, dumper_settings):
+    def _init_dumper_settings(self, dumper_settings: dict | None):
         self._dumper_settings = self._default_dumper_settings.copy()
         if isinstance(dumper_settings, dict):
             self._dumper_settings.update(dumper_settings)
@@ -754,7 +759,7 @@ class PhonopyYamlDumper(PhonopyYamlDumperBase):
             self._data.dataset, with_forces=with_forces
         )
 
-    def _nac_yaml_lines(self):
+    def _nac_yaml_lines(self) -> list:
         if self._data.primitive is None:
             symbols = []
         else:
@@ -825,23 +830,6 @@ class PhonopyYaml:
     default_filenames = ("phonopy_disp.yaml", "phonopy.yaml")
     command_name = "phonopy"
 
-    configuration = phonopy_yaml_property_factory("configuration")
-    calculator = phonopy_yaml_property_factory("calculator")
-    physical_units = phonopy_yaml_property_factory("physical_units")
-    unitcell = phonopy_yaml_property_factory("unitcell")
-    primitive = phonopy_yaml_property_factory("primitive")
-    supercell = phonopy_yaml_property_factory("supercell")
-    dataset = phonopy_yaml_property_factory("dataset")
-    supercell_matrix = phonopy_yaml_property_factory("supercell_matrix")
-    primitive_matrix = phonopy_yaml_property_factory("primitive_matrix")
-    nac_params = phonopy_yaml_property_factory("nac_params")
-    force_constants = phonopy_yaml_property_factory("force_constants")
-    symmetry = phonopy_yaml_property_factory("symmetry")
-    frequency_unit_conversion_factor = phonopy_yaml_property_factory(
-        "frequency_unit_conversion_factor"
-    )
-    version = phonopy_yaml_property_factory("version")
-
     def __init__(
         self, configuration=None, calculator=None, physical_units=None, settings=None
     ):
@@ -866,6 +854,153 @@ class PhonopyYaml:
         )
         self._dumper_settings = settings
 
+    @property
+    def configuration(self) -> dict | None:
+        """Return configuration of phonopy calculation."""
+        return self._data.configuration
+
+    @configuration.setter
+    def configuration(self, value: dict):
+        """Set configuration of phonopy calculation."""
+        self._data.configuration = value
+
+    @property
+    def calculator(self) -> str | None:
+        """Return calculator of phonopy calculation."""
+        return self._data.calculator
+
+    @calculator.setter
+    def calculator(self, value: str):
+        """Set calculator of phonopy calculation."""
+        self._data.calculator = value
+
+    @property
+    def physical_units(self) -> dict | None:
+        """Return physical units of phonopy calculation."""
+        return self._data.physical_units
+
+    @physical_units.setter
+    def physical_units(self, value: dict):
+        """Set physical units of phonopy calculation."""
+        self._data.physical_units = value
+
+    @property
+    def unitcell(self) -> PhonopyAtoms | None:
+        """Return unit cell of phonopy calculation."""
+        return self._data.unitcell
+
+    @unitcell.setter
+    def unitcell(self, value: PhonopyAtoms):
+        """Set unit cell of phonopy calculation."""
+        self._data.unitcell = value
+
+    @property
+    def primitive(self) -> PhonopyAtoms | None:
+        """Return primitive cell of phonopy calculation."""
+        return self._data.primitive
+
+    @primitive.setter
+    def primitive(self, value: PhonopyAtoms):
+        """Set primitive cell of phonopy calculation."""
+        self._data.primitive = value
+
+    @property
+    def supercell(self) -> PhonopyAtoms | None:
+        """Return supercell of phonopy calculation."""
+        return self._data.supercell
+
+    @supercell.setter
+    def supercell(self, value: PhonopyAtoms):
+        """Set supercell of phonopy calculation."""
+        self._data.supercell = value
+
+    @property
+    def dataset(self) -> dict | None:
+        """Return dataset of phonopy calculation."""
+        return self._data.dataset
+
+    @dataset.setter
+    def dataset(self, value: dict):
+        """Set dataset of phonopy calculation."""
+        self._data.dataset = value
+
+    @property
+    def supercell_matrix(self) -> NDArray | None:
+        """Return supercell matrix of phonopy calculation."""
+        return self._data.supercell_matrix
+
+    @supercell_matrix.setter
+    def supercell_matrix(self, value: ArrayLike):
+        """Set supercell matrix of phonopy calculation."""
+        self._data.supercell_matrix = np.array(value, dtype="intc", order="C")
+
+    @property
+    def primitive_matrix(self) -> NDArray | None:
+        """Return primitive matrix of phonopy calculation."""
+        return self._data.primitive_matrix
+
+    @primitive_matrix.setter
+    def primitive_matrix(self, value: ArrayLike):
+        """Set primitive matrix of phonopy calculation."""
+        self._data.primitive_matrix = np.array(value, dtype="double", order="C")
+
+    @property
+    def nac_params(self) -> dict | None:
+        """Return non-analytical term correction parameters."""
+        return self._data.nac_params
+
+    @nac_params.setter
+    def nac_params(self, value: dict):
+        """Set non-analytical term correction parameters."""
+        if value is not None:
+            if "born" in value:
+                value["born"] = np.array(value["born"], dtype="double", order="C")
+            if "dielectric" in value:
+                value["dielectric"] = np.array(
+                    value["dielectric"], dtype="double", order="C"
+                )
+        self._data.nac_params = value
+
+    @property
+    def force_constants(self) -> NDArray | None:
+        """Return force constants of phonopy calculation."""
+        return self._data.force_constants
+
+    @force_constants.setter
+    def force_constants(self, value: ArrayLike):
+        """Set force constants of phonopy calculation."""
+        self._data.force_constants = np.array(value, dtype="double", order="C")
+
+    @property
+    def symmetry(self) -> Symmetry | None:
+        """Return symmetry of phonopy calculation."""
+        return self._data.symmetry
+
+    @symmetry.setter
+    def symmetry(self, value: Symmetry):
+        """Set symmetry of phonopy calculation."""
+        self._data.symmetry = value
+
+    @property
+    def frequency_unit_conversion_factor(self) -> float | None:
+        """Return frequency unit conversion factor."""
+        return self._data.frequency_unit_conversion_factor
+
+    @frequency_unit_conversion_factor.setter
+    def frequency_unit_conversion_factor(self, value: float):
+        """Set frequency unit conversion factor."""
+        self._data.frequency_unit_conversion_factor = value
+
+    @property
+    def version(self) -> str | None:
+        """Return version of phonopy calculation."""
+        return self._data.version
+
+    @version.setter
+    def version(self, value: str):
+        """Set version of phonopy calculation."""
+        self._data.version = value
+
     def __str__(self):
         """Return string text of yaml output."""
         phyml_dumper = PhonopyYamlDumper(
@@ -873,7 +1008,7 @@ class PhonopyYaml:
         )
         return "\n".join(phyml_dumper.get_yaml_lines())
 
-    def read(self, filename: Union[str, bytes, os.PathLike, io.IOBase]):
+    def read(self, filename: str | bytes | os.PathLike | io.IOBase):
         """Read PhonopyYaml file."""
         self._data = read_phonopy_yaml(
             filename,
@@ -901,7 +1036,7 @@ class PhonopyYaml:
 
 
 def read_phonopy_yaml(
-    filename: Union[str, bytes, os.PathLike, io.IOBase],
+    filename: str | bytes | os.PathLike | io.IOBase,
     configuration=None,
     calculator=None,
     physical_units=None,
@@ -944,7 +1079,7 @@ def load_phonopy_yaml(
 
 
 def read_cell_yaml(
-    filename: Union[str, bytes, os.PathLike, io.IOBase], cell_type: str = "unitcell"
+    filename: str | bytes | os.PathLike | io.IOBase, cell_type: str = "unitcell"
 ) -> PhonopyAtoms:
     """Read crystal structure from a phonopy.yaml or PhonopyAtoms.__str__ like file.
 
@@ -991,7 +1126,7 @@ def read_cell_yaml(
             raise RuntimeError(f'Crystal structure data was not found in "{filename}".')
 
 
-def load_yaml(fp: Union[str, bytes, os.PathLike, io.IOBase]):
+def load_yaml(fp: str | bytes | os.PathLike | io.IOBase):
     """Load yaml file.
 
     Parameters
